# This file is generated by objective.metadata
#
# Last update: Sat Mar 21 15:29:39 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
misc.update(
    {
        "QTTimeRange": objc.createStructType(
            "QTTimeRange",
            sel32or64(
                b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
            ),
            ["time", "duration"],
        ),
        "QTTime": objc.createStructType(
            "QTTime",
            sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}"),
            ["timeValue", "timeScale", "flags"],
        ),
    }
)
constants = """$QTAddImageCodecQuality$QTAddImageCodecType$QTCaptureConnectionAttributeDidChangeNotification$QTCaptureConnectionAttributeWillChangeNotification$QTCaptureConnectionAudioAveragePowerLevelsAttribute$QTCaptureConnectionAudioMasterVolumeAttribute$QTCaptureConnectionAudioPeakHoldLevelsAttribute$QTCaptureConnectionAudioVolumesAttribute$QTCaptureConnectionChangedAttributeKey$QTCaptureConnectionEnabledAudioChannelsAttribute$QTCaptureConnectionFormatDescriptionDidChangeNotification$QTCaptureConnectionFormatDescriptionWillChangeNotification$QTCaptureDeviceAVCTransportControlsAttribute$QTCaptureDeviceAVCTransportControlsPlaybackModeKey$QTCaptureDeviceAVCTransportControlsSpeedKey$QTCaptureDeviceAttributeDidChangeNotification$QTCaptureDeviceAttributeWillChangeNotification$QTCaptureDeviceAvailableInputSourcesAttribute$QTCaptureDeviceChangedAttributeKey$QTCaptureDeviceFormatDescriptionsDidChangeNotification$QTCaptureDeviceFormatDescriptionsWillChangeNotification$QTCaptureDeviceInputSourceIdentifierAttribute$QTCaptureDeviceInputSourceIdentifierKey$QTCaptureDeviceInputSourceLocalizedDisplayNameKey$QTCaptureDeviceLegacySequenceGrabberAttribute$QTCaptureDeviceLinkedDevicesAttribute$QTCaptureDeviceSuspendedAttribute$QTCaptureDeviceWasConnectedNotification$QTCaptureDeviceWasDisconnectedNotification$QTCaptureSessionErrorKey$QTCaptureSessionRuntimeErrorNotification$QTDataReferenceTypeFile$QTDataReferenceTypeHandle$QTDataReferenceTypePointer$QTDataReferenceTypeResource$QTDataReferenceTypeURL$QTDisallowedForInitializationPurposeException$QTErrorCaptureInputKey$QTErrorCaptureOutputKey$QTErrorDeviceKey$QTErrorExcludingDeviceKey$QTErrorFileSizeKey$QTErrorRecordingSuccesfullyFinishedKey$QTErrorRecordingSuccessfullyFinishedKey$QTErrorTimeKey$QTExportOptionsAppleM4A$QTExportOptionsAppleM4V480pSD$QTExportOptionsAppleM4V720pHD$QTExportOptionsAppleM4VAppleTV$QTExportOptionsAppleM4VCellular$QTExportOptionsAppleM4VWiFi$QTExportOptionsAppleM4ViPod$QTExportOptionsQuickTimeMovie1080p$QTExportOptionsQuickTimeMovie480p$QTExportOptionsQuickTimeMovie720p$QTFormatDescriptionAudioChannelLayoutAttribute$QTFormatDescriptionAudioMagicCookieAttribute$QTFormatDescriptionAudioStreamBasicDescriptionAttribute$QTFormatDescriptionVideoCleanApertureDisplaySizeAttribute$QTFormatDescriptionVideoEncodedPixelsSizeAttribute$QTFormatDescriptionVideoProductionApertureDisplaySizeAttribute$QTKitErrorDomain$QTMediaCharacteristicAudio$QTMediaCharacteristicCanSendVideo$QTMediaCharacteristicCanStep$QTMediaCharacteristicHasNoDuration$QTMediaCharacteristicHasSkinData$QTMediaCharacteristicHasVideoFrameRate$QTMediaCharacteristicNonLinear$QTMediaCharacteristicProvidesActions$QTMediaCharacteristicProvidesKeyFocus$QTMediaCharacteristicVisual$QTMediaCreationTimeAttribute$QTMediaDurationAttribute$QTMediaModificationTimeAttribute$QTMediaQualityAttribute$QTMediaSampleCountAttribute$QTMediaTimeScaleAttribute$QTMediaType3D$QTMediaTypeAttribute$QTMediaTypeBase$QTMediaTypeClosedCaption$QTMediaTypeFlash$QTMediaTypeHint$QTMediaTypeMPEG$QTMediaTypeMovie$QTMediaTypeMusic$QTMediaTypeMuxed$QTMediaTypeQTVR$QTMediaTypeQuartzComposer$QTMediaTypeSkin$QTMediaTypeSound$QTMediaTypeSprite$QTMediaTypeStream$QTMediaTypeSubtitle$QTMediaTypeText$QTMediaTypeTimeCode$QTMediaTypeTween$QTMediaTypeVideo$QTMetadata3GPUserDataKeyAuthor$QTMetadata3GPUserDataKeyCopyright$QTMetadata3GPUserDataKeyDescription$QTMetadata3GPUserDataKeyGenre$QTMetadata3GPUserDataKeyLocation$QTMetadata3GPUserDataKeyPerformer$QTMetadata3GPUserDataKeyRecordingYear$QTMetadata3GPUserDataKeyTitle$QTMetadataCommonKeyAlbumName$QTMetadataCommonKeyArtist$QTMetadataCommonKeyArtwork$QTMetadataCommonKeyAuthor$QTMetadataCommonKeyComment$QTMetadataCommonKeyContributor$QTMetadataCommonKeyCopyrights$QTMetadataCommonKeyCreationDate$QTMetadataCommonKeyCreator$QTMetadataCommonKeyDescription$QTMetadataCommonKeyFormat$QTMetadataCommonKeyIdentifier$QTMetadataCommonKeyLanguage$QTMetadataCommonKeyLastModifiedDate$QTMetadataCommonKeyLocation$QTMetadataCommonKeyMake$QTMetadataCommonKeyModel$QTMetadataCommonKeyPublisher$QTMetadataCommonKeyRelation$QTMetadataCommonKeySoftware$QTMetadataCommonKeySource$QTMetadataCommonKeySubject$QTMetadataCommonKeyTitle$QTMetadataCommonKeyType$QTMetadataFormatID3Metadata$QTMetadataFormatQuickTimeMetadata$QTMetadataFormatQuickTimeUserData$QTMetadataFormatiTunesMetadata$QTMetadataID3MetadataKeyAlbumSortOrder$QTMetadataID3MetadataKeyAlbumTitle$QTMetadataID3MetadataKeyAttachedPicture$QTMetadataID3MetadataKeyAudioEncryption$QTMetadataID3MetadataKeyAudioSeekPointIndex$QTMetadataID3MetadataKeyBand$QTMetadataID3MetadataKeyBeatsPerMinute$QTMetadataID3MetadataKeyComments$QTMetadataID3MetadataKeyCommercialInformation$QTMetadataID3MetadataKeyCommerical$QTMetadataID3MetadataKeyComposer$QTMetadataID3MetadataKeyConductor$QTMetadataID3MetadataKeyContentGroupDescription$QTMetadataID3MetadataKeyContentType$QTMetadataID3MetadataKeyCopyright$QTMetadataID3MetadataKeyCopyrightInformation$QTMetadataID3MetadataKeyDate$QTMetadataID3MetadataKeyEncodedBy$QTMetadataID3MetadataKeyEncodedWith$QTMetadataID3MetadataKeyEncodingTime$QTMetadataID3MetadataKeyEncryption$QTMetadataID3MetadataKeyEqualization$QTMetadataID3MetadataKeyEqualization2$QTMetadataID3MetadataKeyEventTimingCodes$QTMetadataID3MetadataKeyFileOwner$QTMetadataID3MetadataKeyFileType$QTMetadataID3MetadataKeyGeneralEncapsulatedObject$QTMetadataID3MetadataKeyGroupIdentifier$QTMetadataID3MetadataKeyInitialKey$QTMetadataID3MetadataKeyInternationalStandardRecordingCode$QTMetadataID3MetadataKeyInternetRadioStationName$QTMetadataID3MetadataKeyInternetRadioStationOwner$QTMetadataID3MetadataKeyInvolvedPeopleList_v23$QTMetadataID3MetadataKeyInvolvedPeopleList_v24$QTMetadataID3MetadataKeyLanguage$QTMetadataID3MetadataKeyLeadPerformer$QTMetadataID3MetadataKeyLength$QTMetadataID3MetadataKeyLink$QTMetadataID3MetadataKeyLyricist$QTMetadataID3MetadataKeyMPEGLocationLookupTable$QTMetadataID3MetadataKeyMediaType$QTMetadataID3MetadataKeyModifiedBy$QTMetadataID3MetadataKeyMood$QTMetadataID3MetadataKeyMusicCDIdentifier$QTMetadataID3MetadataKeyMusicianCreditsList$QTMetadataID3MetadataKeyOfficialArtistWebpage$QTMetadataID3MetadataKeyOfficialAudioFileWebpage$QTMetadataID3MetadataKeyOfficialAudioSourceWebpage$QTMetadataID3MetadataKeyOfficialInternetRadioStationHomepage$QTMetadataID3MetadataKeyOfficialPublisherWebpage$QTMetadataID3MetadataKeyOriginalAlbumTitle$QTMetadataID3MetadataKeyOriginalArtist$QTMetadataID3MetadataKeyOriginalFilename$QTMetadataID3MetadataKeyOriginalLyricist$QTMetadataID3MetadataKeyOriginalReleaseTime$QTMetadataID3MetadataKeyOriginalReleaseYear$QTMetadataID3MetadataKeyOwnership$QTMetadataID3MetadataKeyPartOfASet$QTMetadataID3MetadataKeyPayment$QTMetadataID3MetadataKeyPerformerSortOrder$QTMetadataID3MetadataKeyPlayCounter$QTMetadataID3MetadataKeyPlaylistDelay$QTMetadataID3MetadataKeyPopularimeter$QTMetadataID3MetadataKeyPositionSynchronization$QTMetadataID3MetadataKeyPrivate$QTMetadataID3MetadataKeyProducedNotice$QTMetadataID3MetadataKeyPublisher$QTMetadataID3MetadataKeyRecommendedBufferSize$QTMetadataID3MetadataKeyRecordingDates$QTMetadataID3MetadataKeyRecordingTime$QTMetadataID3MetadataKeyRelativeVolumeAdjustment$QTMetadataID3MetadataKeyRelativeVolumeAdjustment2$QTMetadataID3MetadataKeyReleaseTime$QTMetadataID3MetadataKeyReverb$QTMetadataID3MetadataKeySeek$QTMetadataID3MetadataKeySetSubtitle$QTMetadataID3MetadataKeySignature$QTMetadataID3MetadataKeySize$QTMetadataID3MetadataKeySubTitle$QTMetadataID3MetadataKeySynchronizedLyric$QTMetadataID3MetadataKeySynchronizedTempoCodes$QTMetadataID3MetadataKeyTaggingTime$QTMetadataID3MetadataKeyTermsOfUse$QTMetadataID3MetadataKeyTime$QTMetadataID3MetadataKeyTitleDescription$QTMetadataID3MetadataKeyTitleSortOrder$QTMetadataID3MetadataKeyTrackNumber$QTMetadataID3MetadataKeyUniqueFileIdentifier$QTMetadataID3MetadataKeyUnsynchronizedLyric$QTMetadataID3MetadataKeyUserText$QTMetadataID3MetadataKeyUserURL$QTMetadataID3MetadataKeyYear$QTMetadataISOUserDataKeyCopyright$QTMetadataKeySpaceCommon$QTMetadataKeySpaceID3$QTMetadataKeySpaceQuickTimeMetadata$QTMetadataKeySpaceQuickTimeUserData$QTMetadataKeySpaceiTunes$QTMetadataQuickTimeMetadataKeyAlbum$QTMetadataQuickTimeMetadataKeyArranger$QTMetadataQuickTimeMetadataKeyArtist$QTMetadataQuickTimeMetadataKeyArtwork$QTMetadataQuickTimeMetadataKeyAuthor$QTMetadataQuickTimeMetadataKeyComment$QTMetadataQuickTimeMetadataKeyComposer$QTMetadataQuickTimeMetadataKeyCopyright$QTMetadataQuickTimeMetadataKeyCreationDate$QTMetadataQuickTimeMetadataKeyCredits$QTMetadataQuickTimeMetadataKeyDescription$QTMetadataQuickTimeMetadataKeyDirector$QTMetadataQuickTimeMetadataKeyDisplayName$QTMetadataQuickTimeMetadataKeyEncodedBy$QTMetadataQuickTimeMetadataKeyGenre$QTMetadataQuickTimeMetadataKeyInformation$QTMetadataQuickTimeMetadataKeyKeywords$QTMetadataQuickTimeMetadataKeyLocationISO6709$QTMetadataQuickTimeMetadataKeyMake$QTMetadataQuickTimeMetadataKeyModel$QTMetadataQuickTimeMetadataKeyOriginalArtist$QTMetadataQuickTimeMetadataKeyPerformer$QTMetadataQuickTimeMetadataKeyPhonogramRights$QTMetadataQuickTimeMetadataKeyProducer$QTMetadataQuickTimeMetadataKeyPublisher$QTMetadataQuickTimeMetadataKeySoftware$QTMetadataQuickTimeMetadataKeyYear$QTMetadataQuickTimeMetadataKeyiXML$QTMetadataQuickTimeUserDataKeyAlbum$QTMetadataQuickTimeUserDataKeyArranger$QTMetadataQuickTimeUserDataKeyArtist$QTMetadataQuickTimeUserDataKeyAuthor$QTMetadataQuickTimeUserDataKeyChapter$QTMetadataQuickTimeUserDataKeyComment$QTMetadataQuickTimeUserDataKeyComposer$QTMetadataQuickTimeUserDataKeyCopyright$QTMetadataQuickTimeUserDataKeyCreationDate$QTMetadataQuickTimeUserDataKeyCredits$QTMetadataQuickTimeUserDataKeyDescription$QTMetadataQuickTimeUserDataKeyDirector$QTMetadataQuickTimeUserDataKeyDisclaimer$QTMetadataQuickTimeUserDataKeyEncodedBy$QTMetadataQuickTimeUserDataKeyFullName$QTMetadataQuickTimeUserDataKeyGenre$QTMetadataQuickTimeUserDataKeyHostComputer$QTMetadataQuickTimeUserDataKeyInformation$QTMetadataQuickTimeUserDataKeyKeywords$QTMetadataQuickTimeUserDataKeyLocationISO6709$QTMetadataQuickTimeUserDataKeyMake$QTMetadataQuickTimeUserDataKeyModel$QTMetadataQuickTimeUserDataKeyOriginalArtist$QTMetadataQuickTimeUserDataKeyOriginalFormat$QTMetadataQuickTimeUserDataKeyOriginalSource$QTMetadataQuickTimeUserDataKeyPerformers$QTMetadataQuickTimeUserDataKeyPhonogramRights$QTMetadataQuickTimeUserDataKeyProducer$QTMetadataQuickTimeUserDataKeyProduct$QTMetadataQuickTimeUserDataKeyPublisher$QTMetadataQuickTimeUserDataKeySoftware$QTMetadataQuickTimeUserDataKeySpecialPlaybackRequirements$QTMetadataQuickTimeUserDataKeyTrack$QTMetadataQuickTimeUserDataKeyTrackName$QTMetadataQuickTimeUserDataKeyURLLink$QTMetadataQuickTimeUserDataKeyWarning$QTMetadataQuickTimeUserDataKeyWriter$QTMetadataiTunesMetadataKeyAccountKind$QTMetadataiTunesMetadataKeyAcknowledgement$QTMetadataiTunesMetadataKeyAlbum$QTMetadataiTunesMetadataKeyAlbumArtist$QTMetadataiTunesMetadataKeyAppleID$QTMetadataiTunesMetadataKeyArranger$QTMetadataiTunesMetadataKeyArtDirector$QTMetadataiTunesMetadataKeyArtist$QTMetadataiTunesMetadataKeyArtistID$QTMetadataiTunesMetadataKeyAuthor$QTMetadataiTunesMetadataKeyBeatsPerMin$QTMetadataiTunesMetadataKeyComposer$QTMetadataiTunesMetadataKeyConductor$QTMetadataiTunesMetadataKeyContentRating$QTMetadataiTunesMetadataKeyCopyright$QTMetadataiTunesMetadataKeyCoverArt$QTMetadataiTunesMetadataKeyCredits$QTMetadataiTunesMetadataKeyDescription$QTMetadataiTunesMetadataKeyDirector$QTMetadataiTunesMetadataKeyDiscCompilation$QTMetadataiTunesMetadataKeyDiscNumber$QTMetadataiTunesMetadataKeyEQ$QTMetadataiTunesMetadataKeyEncodedBy$QTMetadataiTunesMetadataKeyEncodingTool$QTMetadataiTunesMetadataKeyExecProducer$QTMetadataiTunesMetadataKeyGenreID$QTMetadataiTunesMetadataKeyGrouping$QTMetadataiTunesMetadataKeyLinerNotes$QTMetadataiTunesMetadataKeyLyrics$QTMetadataiTunesMetadataKeyOnlineExtras$QTMetadataiTunesMetadataKeyOriginalArtist$QTMetadataiTunesMetadataKeyPerformer$QTMetadataiTunesMetadataKeyPhonogramRights$QTMetadataiTunesMetadataKeyPlaylistID$QTMetadataiTunesMetadataKeyPredefinedGenre$QTMetadataiTunesMetadataKeyProducer$QTMetadataiTunesMetadataKeyPublisher$QTMetadataiTunesMetadataKeyRecordCompany$QTMetadataiTunesMetadataKeyReleaseDate$QTMetadataiTunesMetadataKeySoloist$QTMetadataiTunesMetadataKeySongID$QTMetadataiTunesMetadataKeySongName$QTMetadataiTunesMetadataKeySoundEngineer$QTMetadataiTunesMetadataKeyThanks$QTMetadataiTunesMetadataKeyTrackNumber$QTMetadataiTunesMetadataKeyTrackSubTitle$QTMetadataiTunesMetadataKeyUserComment$QTMetadataiTunesMetadataKeyUserGenre$QTMovieActiveSegmentAttribute$QTMovieApertureModeAttribute$QTMovieApertureModeClassic$QTMovieApertureModeClean$QTMovieApertureModeDidChangeNotification$QTMovieApertureModeEncodedPixels$QTMovieApertureModeProduction$QTMovieAskUnresolvedDataRefsAttribute$QTMovieAutoAlternatesAttribute$QTMovieChapterDidChangeNotification$QTMovieChapterListDidChangeNotification$QTMovieChapterName$QTMovieChapterStartTime$QTMovieChapterTargetTrackAttribute$QTMovieCloseWindowRequestNotification$QTMovieCopyrightAttribute$QTMovieCreationTimeAttribute$QTMovieCurrentSizeAttribute$QTMovieCurrentTimeAttribute$QTMovieDataAttribute$QTMovieDataReferenceAttribute$QTMovieDataSizeAttribute$QTMovieDelegateAttribute$QTMovieDidEndNotification$QTMovieDisplayNameAttribute$QTMovieDontInteractWithUserAttribute$QTMovieDurationAttribute$QTMovieEditabilityDidChangeNotification$QTMovieEditableAttribute$QTMovieEditedNotification$QTMovieEnterFullScreenRequestNotification$QTMovieExitFullScreenRequestNotification$QTMovieExport$QTMovieExportManufacturer$QTMovieExportSettings$QTMovieExportType$QTMovieFileNameAttribute$QTMovieFileOffsetAttribute$QTMovieFlatten$QTMovieFrameImageDeinterlaceFields$QTMovieFrameImageHighQuality$QTMovieFrameImageOpenGLContext$QTMovieFrameImagePixelFormat$QTMovieFrameImageRepresentationsType$QTMovieFrameImageSessionMode$QTMovieFrameImageSingleField$QTMovieFrameImageSize$QTMovieFrameImageType$QTMovieFrameImageTypeCGImageRef$QTMovieFrameImageTypeCIImage$QTMovieFrameImageTypeCVOpenGLTextureRef$QTMovieFrameImageTypeCVPixelBufferRef$QTMovieFrameImageTypeNSImage$QTMovieHasApertureModeDimensionsAttribute$QTMovieHasAudioAttribute$QTMovieHasDurationAttribute$QTMovieHasVideoAttribute$QTMovieIsActiveAttribute$QTMovieIsInteractiveAttribute$QTMovieIsLinearAttribute$QTMovieIsSteppableAttribute$QTMovieLoadStateAttribute$QTMovieLoadStateDidChangeNotification$QTMovieLoadStateErrorAttribute$QTMovieLoopModeDidChangeNotification$QTMovieLoopsAttribute$QTMovieLoopsBackAndForthAttribute$QTMovieMessageNotificationParameter$QTMovieMessageStringPostedNotification$QTMovieModernizerOutputFormat_AppleProRes422$QTMovieModernizerOutputFormat_AppleProRes4444$QTMovieModernizerOutputFormat_H264$QTMovieModificationTimeAttribute$QTMovieMutedAttribute$QTMovieNaturalSizeAttribute$QTMovieNaturalSizeDidChangeNotification$QTMovieOpenAsyncOKAttribute$QTMovieOpenAsyncRequiredAttribute$QTMovieOpenForPlaybackAttribute$QTMoviePasteboardAttribute$QTMoviePasteboardType$QTMoviePlaysAllFramesAttribute$QTMoviePlaysSelectionOnlyAttribute$QTMoviePosterTimeAttribute$QTMoviePreferredMutedAttribute$QTMoviePreferredRateAttribute$QTMoviePreferredVolumeAttribute$QTMoviePreviewModeAttribute$QTMoviePreviewRangeAttribute$QTMovieRateAttribute$QTMovieRateChangesPreservePitchAttribute$QTMovieRateDidChangeNotification$QTMovieRateDidChangeNotificationParameter$QTMovieResolveDataRefsAttribute$QTMovieSelectionAttribute$QTMovieSelectionDidChangeNotification$QTMovieSizeDidChangeNotification$QTMovieStatusCodeNotificationParameter$QTMovieStatusFlagsNotificationParameter$QTMovieStatusStringNotificationParameter$QTMovieStatusStringPostedNotification$QTMovieTargetIDNotificationParameter$QTMovieTargetNameNotificationParameter$QTMovieTimeDidChangeNotification$QTMovieTimeScaleAttribute$QTMovieURLAttribute$QTMovieUneditableException$QTMovieViewControllerVisibleBinding$QTMovieViewFillColorBinding$QTMovieViewMovieBinding$QTMovieViewPreservesAspectRatioBinding$QTMovieVolumeAttribute$QTMovieVolumeDidChangeNotification$QTSampleBufferDateRecordedAttribute$QTSampleBufferExplicitSceneChange$QTSampleBufferHostTimeAttribute$QTSampleBufferSMPTETimeAttribute$QTSampleBufferSceneChangeTypeAttribute$QTSampleBufferTimeStampDiscontinuitySceneChange$QTTrackBoundsAttribute$QTTrackCreationTimeAttribute$QTTrackDimensionsAttribute$QTTrackDisplayNameAttribute$QTTrackEnabledAttribute$QTTrackFormatSummaryAttribute$QTTrackHasApertureModeDimensionsAttribute$QTTrackIDAttribute$QTTrackIsChapterTrackAttribute$QTTrackLayerAttribute$QTTrackMediaTypeAttribute$QTTrackModificationTimeAttribute$QTTrackRangeAttribute$QTTrackTimeScaleAttribute$QTTrackUsageInMovieAttribute$QTTrackUsageInPosterAttribute$QTTrackUsageInPreviewAttribute$QTTrackVolumeAttribute$"""
constants = constants + "$QTIndefiniteTime@%s$" % (
    sel32or64("{_QTTime=qll}", "{_QTTime=qqq}"),
)
constants = constants + "$QTZeroTime@%s$" % (
    sel32or64("{_QTTime=qll}", "{_QTTime=qqq}"),
)
enums = """$AliasDataHandlerSubType@'alis'$AudioMediaCharacteristic@'ears'$BaseMediaType@'gnrc'$DataHandlerType@'dhlr'$FlashMediaType@'flsh'$FreeAtomType@'free'$HandleDataHandlerSubType@'hndl'$MAC_OS_X_VERSION_10_4@1040$MAC_OS_X_VERSION_10_5@1050$MAC_OS_X_VERSION_10_6@1060$MAC_OS_X_VERSION_10_7@1070$MPEGMediaType@'MPEG'$MediaHandlerType@'mhlr'$MovieBackwardPointerResourceType@'back'$MovieDataAtomType@'mdat'$MovieFileType@'MooV'$MovieForwardPointerResourceType@'fore'$MovieMediaType@'moov'$MovieResourceAtomType@'moov'$MovieResourceType@'moov'$MovieScrapType@'moov'$MusicMediaType@'musi'$NSINTEGER_DEFINED@1$NullDataHandlerSubType@'null'$PointerDataHandlerSubType@'ptr '$QTCaptureDeviceAVCTransportControlsFastForwardSpeed@13000$QTCaptureDeviceAVCTransportControlsFastReverseSpeed@-13000$QTCaptureDeviceAVCTransportControlsFastestForwardSpeed@19000$QTCaptureDeviceAVCTransportControlsFastestReverseSpeed@-19000$QTCaptureDeviceAVCTransportControlsNormalForwardSpeed@10000$QTCaptureDeviceAVCTransportControlsNormalReverseSpeed@-10000$QTCaptureDeviceAVCTransportControlsNotPlayingMode@0$QTCaptureDeviceAVCTransportControlsPlayingMode@1$QTCaptureDeviceAVCTransportControlsSlowForwardSpeed@7000$QTCaptureDeviceAVCTransportControlsSlowReverseSpeed@-7000$QTCaptureDeviceAVCTransportControlsSlowestForwardSpeed@1000$QTCaptureDeviceAVCTransportControlsSlowestReverseSpeed@-1000$QTCaptureDeviceAVCTransportControlsStoppedSpeed@0$QTCaptureDeviceAVCTransportControlsVeryFastForwardSpeed@16000$QTCaptureDeviceAVCTransportControlsVeryFastReverseSpeed@-16000$QTCaptureDeviceAVCTransportControlsVerySlowForwardSpeed@4000$QTCaptureDeviceAVCTransportControlsVerySlowReverseSpeed@-4000$QTCaptureFileOutputBufferDestinationNewFile@1$QTCaptureFileOutputBufferDestinationOldFile@2$QTErrorDeviceAlreadyUsedbyAnotherSession@1101$QTErrorDeviceExcludedByAnotherDevice@1302$QTErrorDeviceInUseByAnotherApplication@1301$QTErrorDeviceNotConnected@1300$QTErrorDeviceWasDisconnected@1203$QTErrorDiskFull@1202$QTErrorExportExecutionFailed@1503$QTErrorExportIOError@1506$QTErrorExportInsufficientSpaceOnDevice@1504$QTErrorExportNoSuchDirectoryOrFile@1505$QTErrorIncompatibleInput@1002$QTErrorIncompatibleOutput@1003$QTErrorInvalidDestinationFileTypeForExport@1501$QTErrorInvalidInputsOrOutputs@1100$QTErrorInvalidSourceFileTypeForExport@1502$QTErrorMaximumDurationReached@1205$QTErrorMaximumFileSizeReached@1206$QTErrorMaximumNumberOfSamplesForFileFormatReached@1208$QTErrorMediaChanged@1204$QTErrorMediaDiscontinuity@1207$QTErrorNoDataCaptured@1200$QTErrorSessionConfigurationChanged@1201$QTErrorUnknown@-1$QTIncludeAggressiveTypes@4$QTIncludeAllTypes@65535$QTIncludeCommonTypes@0$QTIncludeDynamicTypes@8$QTIncludeStillImageTypes@1$QTIncludeTranslatableTypes@2$QTKIT_VERSION_7_0@70000$QTKIT_VERSION_7_2@70200$QTKIT_VERSION_7_6_3@70603$QTKIT_VERSION_7_6_6@70606$QTKIT_VERSION_7_7@70700$QTKIT_VERSION_7_7_2@70702$QTKIT_VERSION_7_7_3@70703$QTMovieLoadStateComplete@100000$QTMovieLoadStateError@-1$QTMovieLoadStateLoaded@2000$QTMovieLoadStateLoading@1000$QTMovieLoadStatePlayable@10000$QTMovieLoadStatePlaythroughOK@20000$QTMovieModernizerStatusCancelled@3$QTMovieModernizerStatusCompletedWithSuccess@5$QTMovieModernizerStatusFailed@4$QTMovieModernizerStatusNotRequired@6$QTMovieModernizerStatusPreparing@1$QTMovieModernizerStatusRunning@2$QTMovieModernizerStatusUnknown@0$QTMovieOperationBeginPhase@0$QTMovieOperationEndPhase@2$QTMovieOperationUpdatePercentPhase@1$QTSampleBufferAudioBufferListOptionAssure16ByteAlignment@1$ResourceDataHandlerSubType@'rsrc'$SkinMediaType@'skin'$SkipAtomType@'skip'$SoundMediaType@'soun'$SpriteMediaType@'sprt'$TextMediaType@'text'$ThreeDeeMediaType@'qd3d'$TimeCode64MediaType@'tc64'$TimeCodeMediaType@'tmcd'$TweenMediaType@'twen'$URLDataHandlerSubType@'url '$VideoMediaType@'vide'$VisualMediaCharacteristic@'eyes'$WideAtomPlaceholderType@'wide'$WiredActionHandlerType@'wire'$codecHighQuality@768$codecLosslessQuality@1024$codecLowQuality@256$codecMaxQuality@1023$codecMinQuality@0$codecNormalQuality@512$graphicsModeComposition@259$graphicsModePerComponentAlpha@272$graphicsModePreBlackAlpha@258$graphicsModePreMulColorAlpha@261$graphicsModePreWhiteAlpha@257$graphicsModeStraightAlpha@256$graphicsModeStraightAlphaBlend@260$k16GrayCodecType@'b16g'$k32AlphaGrayCodecType@'b32a'$k422YpCbCr10CodecType@'v210'$k422YpCbCr16CodecType@'v216'$k422YpCbCr8CodecType@'2vuy'$k4444YpCbCrA8CodecType@'v408'$k4444YpCbCrA8RCodecType@'r408'$k444YpCbCr10CodecType@'v410'$k444YpCbCr8CodecType@'v308'$k48RGBCodecType@'b48r'$k64ARGBCodecType@'b64a'$kAVRJPEGCodecType@'avr '$kAnimationCodecType@'rle '$kBMPCodecType@'WRLE'$kBaseCodecType@'base'$kCMYKCodecType@'cmyk'$kCharacteristicCanSendVideo@'vsnd'$kCharacteristicCanStep@'step'$kCharacteristicHasNoDuration@'noti'$kCharacteristicHasSkinData@'skin'$kCharacteristicNonLinear@'nonl'$kCharacteristicProvidesActions@'actn'$kCharacteristicProvidesKeyFocus@'keyf'$kCharacteristicSupportsDisplayOffsets@'dtdd'$kCinepakCodecType@'cvid'$kCloudCodecType@'clou'$kComponentVideoCodecType@'yuv2'$kComponentVideoSigned@'yuvu'$kComponentVideoUnsigned@'yuvs'$kDVCNTSCCodecType@'dvc '$kDVCPALCodecType@'dvcp'$kDVCPROHD1080i50CodecType@'dvh5'$kDVCPROHD1080i60CodecType@'dvh6'$kDVCPROHD1080p25CodecType@'dvh2'$kDVCPROHD1080p30CodecType@'dvh3'$kDVCPROHD720p50CodecType@'dvhq'$kDVCPROHD720p60CodecType@'dvhp'$kDVCPROHD720pCodecType@'dvhp'$kDVCPro100NTSCCodecType@'dv1n'$kDVCPro100PALCodecType@'dv1p'$kDVCPro50NTSCCodecType@'dv5n'$kDVCPro50PALCodecType@'dv5p'$kDVCProPALCodecType@'dvpp'$kFLCCodecType@'flic'$kFireCodecType@'fire'$kGIFCodecType@'gif '$kGraphicsCodecType@'smc '$kH261CodecType@'h261'$kH263CodecType@'h263'$kH264CodecType@'avc1'$kIndeo4CodecType@'IV41'$kJPEG2000CodecType@'mjp2'$kJPEGCodecType@'jpeg'$kMPEG4VisualCodecType@'mp4v'$kMacPaintCodecType@'PNTG'$kMicrosoftVideo1CodecType@'msvc'$kMotionJPEGACodecType@'mjpa'$kMotionJPEGBCodecType@'mjpb'$kMpegYUV420CodecType@'myuv'$kOpenDMLJPEGCodecType@'dmb1'$kPNGCodecType@'png '$kPhotoCDCodecType@'kpcd'$kPixletCodecType@'pxlt'$kPlanarRGBCodecType@'8BPS'$kQTAnimatedGIFLoopCountInfinite@0$kQTFileType3DMF@860114246$kQTFileType3GP2@862416946$kQTFileType3GPP@862417008$kQTFileTypeAIFC@1095321155$kQTFileTypeAIFF@1095321158$kQTFileTypeAMC@1634558752$kQTFileTypeAMR@1634562592$kQTFileTypeAVI@1449547552$kQTFileTypeAudioCDTrack@1953653099$kQTFileTypeBMP@1112363110$kQTFileTypeDVC@1685480225$kQTFileTypeFLC@1179403040$kQTFileTypeFlash@1398228556$kQTFileTypeFlashPix@1179675000$kQTFileTypeGIF@1195984486$kQTFileTypeJFIF@1246774599$kQTFileTypeJPEG@1246774599$kQTFileTypeJPEG2000@1785737760$kQTFileTypeMIDI@1298752617$kQTFileTypeMP4@1836082996$kQTFileTypeMacPaint@1347310663$kQTFileTypeMovie@1299148630$kQTFileTypeMuLaw@1431060823$kQTFileTypePDF@1346651680$kQTFileTypePICS@1346978643$kQTFileTypePNG@1347307366$kQTFileTypePhotoShop@943870035$kQTFileTypePicture@1346978644$kQTFileTypeQuickDrawGXPicture@1902405496$kQTFileTypeQuickTimeImage@1903454566$kQTFileTypeSDV@1935963680$kQTFileTypeSGIImage@777209673$kQTFileTypeSoundDesignerII@1399075430$kQTFileTypeSystemSevenSound@1936091500$kQTFileTypeTIFF@1414088262$kQTFileTypeTargaImage@1414547779$kQTFileTypeText@1413830740$kQTFileTypeWave@1463899717$kQTQuartzComposerMediaType@'qtz '$kQTTimeIsIndefinite@1$kQuickDrawCodecType@'qdrw'$kQuickDrawGXCodecType@'qdgx'$kRawCodecType@'raw '$kSGICodecType@'.SGI'$kSorenson3CodecType@'SVQ3'$kSorensonCodecType@'SVQ1'$kSorensonYUV9CodecType@'syv9'$kTIFFCodecType@'tiff'$kTargaCodecType@'tga '$kUserDataAnimatedGIFBufferingSize@'gifb'$kUserDataAnimatedGIFLoopCount@'gifc'$kUserDataMovieControllerType@'ctyp'$kUserDataName@'name'$kUserDataTextAlbum@2841734242$kUserDataTextArtist@2839630420$kUserDataTextAuthor@2841736564$kUserDataTextChapter@2841864304$kUserDataTextComment@2841865588$kUserDataTextComposer@2841866093$kUserDataTextCopyright@2841866361$kUserDataTextCreationDate@2841928057$kUserDataTextDescription@2841929075$kUserDataTextDirector@2841930098$kUserDataTextDisclaimer@2841930099$kUserDataTextEditDate1@2841994289$kUserDataTextEncodedBy@2841996899$kUserDataTextFullName@2842583405$kUserDataTextGenre@2842125678$kUserDataTextHostComputer@2842194804$kUserDataTextInformation@2842259046$kUserDataTextKeywords@2842387833$kUserDataTextMake@2842517867$kUserDataTextModel@2842521444$kUserDataTextOriginalArtist@2842652773$kUserDataTextOriginalFormat@2842062196$kUserDataTextOriginalSource@2842915427$kUserDataTextPerformers@2842718822$kUserDataTextProducer@2842718820$kUserDataTextProduct@2840613444$kUserDataTextPublisher@2842719586$kUserDataTextSoftware@2842916722$kUserDataTextSpecialPlaybackRequirements@2842846577$kUserDataTextTrack@2842980971$kUserDataTextURLLink@2843046508$kUserDataTextWarning@2843177582$kUserDataTextWriter@2843177588$kVectorCodecType@'path'$kVideoCodecType@'rpza'$kWaterRippleCodecType@'ripl'$kWindowsRawCodecType@'WRAW'$kYUV420CodecType@'y420'$"""
misc.update({})
functions = {
    "QTStringForOSType": (sel32or64(b"@L", b"@I"),),
    "QTMakeTimeWithTimeRecord": (
        sel32or64(
            b"{_QTTime=qll}{TimeRecord={wide=Ll}l^{TimeBaseRecord=}}",
            b"{_QTTime=qqq}{TimeRecord={wide=Ii}i^{TimeBaseRecord=}}",
        ),
    ),
    "QTMakeTimeRange": (
        sel32or64(
            b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}{_QTTime=qll}{_QTTime=qll}",
            b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}{_QTTime=qqq}{_QTTime=qqq}",
        ),
    ),
    "QTStringFromTime": (sel32or64(b"@{_QTTime=qll}", b"@{_QTTime=qqq}"),),
    "QTTimeCompare": (
        sel32or64(b"i{_QTTime=qll}{_QTTime=qll}", b"q{_QTTime=qqq}{_QTTime=qqq}"),
    ),
    "QTTimeDecrement": (
        sel32or64(
            b"{_QTTime=qll}{_QTTime=qll}{_QTTime=qll}",
            b"{_QTTime=qqq}{_QTTime=qqq}{_QTTime=qqq}",
        ),
    ),
    "QTMakeTimeWithTimeInterval": (sel32or64(b"{_QTTime=qll}d", b"{_QTTime=qqq}d"),),
    "QTStringFromTimeRange": (
        sel32or64(
            b"@{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
            b"@{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
        ),
    ),
    "QTOSTypeForString": (sel32or64(b"L@", b"I@"),),
    "QTTimeRangeEnd": (
        sel32or64(
            b"{_QTTime=qll}{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
            b"{_QTTime=qqq}{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
        ),
    ),
    "QTTimeFromString": (sel32or64(b"{_QTTime=qll}@", b"{_QTTime=qqq}@"),),
    "QTGetTimeInterval": (
        sel32or64(b"Z{_QTTime=qll}^d", b"Z{_QTTime=qqq}^d"),
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "QTTimeInTimeRange": (
        sel32or64(
            b"Z{_QTTime=qll}{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
            b"Z{_QTTime=qqq}{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
        ),
    ),
    "QTUnionTimeRange": (
        sel32or64(
            b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
            b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
        ),
    ),
    "QTMakeTimeScaled": (
        sel32or64(b"{_QTTime=qll}{_QTTime=qll}l", b"{_QTTime=qqq}{_QTTime=qqq}q"),
    ),
    "QTTimeIncrement": (
        sel32or64(
            b"{_QTTime=qll}{_QTTime=qll}{_QTTime=qll}",
            b"{_QTTime=qqq}{_QTTime=qqq}{_QTTime=qqq}",
        ),
    ),
    "QTTimeIsIndefinite": (sel32or64(b"Z{_QTTime=qll}", b"Z{_QTTime=qqq}"),),
    "QTStringFromSMPTETime": (
        sel32or64(b"@{SMPTETime=ssLLLssss}", b"@{SMPTETime=ssIIIssss}"),
    ),
    "QTMakeTime": (sel32or64(b"{_QTTime=qll}ql", b"{_QTTime=qqq}qq"),),
    "QTTimeRangeFromString": (
        sel32or64(
            b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}@",
            b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}@",
        ),
    ),
    "QTEqualTimeRanges": (
        sel32or64(
            b"Z{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
            b"Z{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
        ),
    ),
    "QTIntersectionTimeRange": (
        sel32or64(
            b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
            b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
        ),
    ),
    "QTGetTimeRecord": (
        sel32or64(
            b"Z{_QTTime=qll}^{TimeRecord={wide=Ii}i^{TimeBaseRecord}}",
            b"Z{_QTTime=qqq}^{TimeRecord={wide=Ii}i^{TimeBaseRecord}}",
        ),
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
}
aliases = {
    "AVAILABLE_QTKIT_VERSION_7_0_AND_LATER_BUT_DEPRECATED_IN_QTKIT_VERSION_7_2": "AVAILABLE_QTKIT_VERSION_7_0_AND_LATER",
    "AVAILABLE_QTKIT_VERSION_7_0_AND_LATER_BUT_DEPRECATED_IN_QTKIT_VERSION_7_6_3": "AVAILABLE_QTKIT_VERSION_7_0_AND_LATER",
    "AVAILABLE_QTKIT_VERSION_7_0_AND_LATER_BUT_DEPRECATED_IN_QTKIT_VERSION_7_7_3": "AVAILABLE_QTKIT_VERSION_7_0_AND_LATER",
    "QTMovieOperationEndPhase": "movieProgressClose",
    "AVAILABLE_QTKIT_VERSION_7_2_AND_LATER": "WEAK_IMPORT_ATTRIBUTE",
    "AVAILABLE_QTKIT_VERSION_7_6_3_AND_LATER_BUT_DEPRECATED_IN_QTKIT_VERSION_7_7_3": "AVAILABLE_QTKIT_VERSION_7_6_3_AND_LATER",
    "AVAILABLE_QTKIT_VERSION_7_7_AND_LATER": "WEAK_IMPORT_ATTRIBUTE",
    "NSIntegerMax": "LONG_MAX",
    "AVAILABLE_QTKIT_VERSION_7_2_AND_LATER_BUT_DEPRECATED_IN_QTKIT_VERSION_7_7": "AVAILABLE_QTKIT_VERSION_7_2_AND_LATER",
    "AVAILABLE_QTKIT_VERSION_7_6_6_AND_LATER_BUT_DEPRECATED_IN_QTKIT_VERSION_7_7_3": "AVAILABLE_QTKIT_VERSION_7_6_6_AND_LATER",
    "QTMovieOperationBeginPhase": "movieProgressOpen",
    "AVAILABLE_QTKIT_VERSION_7_2_AND_LATER_BUT_DEPRECATED_IN_QTKIT_VERSION_7_6_3": "AVAILABLE_QTKIT_VERSION_7_2_AND_LATER",
    "AVAILABLE_QTKIT_VERSION_7_7_2_AND_LATER": "WEAK_IMPORT_ATTRIBUTE",
    "AVAILABLE_QTKIT_VERSION_7_2_AND_LATER_BUT_DEPRECATED_IN_QTKIT_VERSION_7_7_3": "AVAILABLE_QTKIT_VERSION_7_2_AND_LATER",
    "AVAILABLE_QTKIT_VERSION_7_6_6_AND_LATER": "WEAK_IMPORT_ATTRIBUTE",
    "QTMovieOperationUpdatePercentPhase": "movieProgressUpdatePercent",
    "NSUIntegerMax": "ULONG_MAX",
    "QTKIT_VERSION_MIN_REQUIRED": "QTKIT_VERSION_7_0",
    "AVAILABLE_QTKIT_VERSION_7_7_3_AND_LATER": "WEAK_IMPORT_ATTRIBUTE",
    "NSIntegerMin": "LONG_MIN",
    "AVAILABLE_QTKIT_VERSION_7_6_3_AND_LATER": "WEAK_IMPORT_ATTRIBUTE",
    "AVAILABLE_QTKIT_VERSION_7_0_AND_LATER": "WEAK_IMPORT_ATTRIBUTE",
    "AVAILABLE_QTKIT_VERSION_7_7_AND_LATER_BUT_DEPRECATED_IN_QTKIT_VERSION_7_7_3": "AVAILABLE_QTKIT_VERSION_7_7_AND_LATER",
}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSCoder",
        b"decodeQTTimeForKey:",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"NSCoder",
        b"decodeQTTimeRangeForKey:",
        {
            "retval": {
                "type": sel32or64(
                    b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                    b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                )
            }
        },
    )
    r(
        b"NSCoder",
        b"encodeQTTime:forKey:",
        {"arguments": {2: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}}},
    )
    r(
        b"NSCoder",
        b"encodeQTTimeRange:forKey:",
        {
            "arguments": {
                2: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                }
            }
        },
    )
    r(
        b"NSObject",
        b"captureOutput:didDropVideoFrameWithSampleBuffer:fromConnection:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"captureOutput:didFinishRecordingToOutputFileAtURL:forConnections:dueToError:",
        {
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"captureOutput:didOutputAudioSampleBuffer:fromConnection:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"captureOutput:didOutputSampleBuffer:fromConnection:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"captureOutput:didOutputVideoFrame:withSampleBuffer:fromConnection:",
        {
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"^{__CVBuffer=}"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"captureOutput:didPauseRecordingToOutputFileAtURL:forConnections:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"captureOutput:didResumeRecordingToOutputFileAtURL:forConnections:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"captureOutput:didStartRecordingToOutputFileAtURL:forConnections:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"captureOutput:mustChangeOutputFileAtURL:forConnections:dueToError:",
        {
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"captureOutput:shouldChangeOutputFileAtURL:forConnections:dueToError:",
        {
            "retval": {"type": "Z"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"captureOutput:willFinishRecordingToOutputFileAtURL:forConnections:dueToError:",
        {
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"captureOutput:willStartRecordingToOutputFileAtURL:forConnections:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(b"NSObject", b"delegate", {"retval": {"type": b"@"}})
    r(b"NSObject", b"exportSession:didReachProgess:", {"arguments": {3: {"type": "d"}}})
    r(
        b"NSObject",
        b"menuForEventDelegate:",
        {"retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"NSObject", b"movie:linkToURL:", {"retval": {"type": "Z"}})
    r(
        b"NSObject",
        b"movie:shouldContinueOperation:withPhase:atPercent:withAttributes:",
        {"retval": {"type": "Z"}, "arguments": {4: {"type": "i"}}},
    )
    r(b"NSObject", b"movieShouldLoadData:", {"retval": {"type": "Z"}})
    r(b"NSObject", b"movieShouldTask:", {"retval": {"type": "Z"}})
    r(
        b"NSObject",
        b"setDelegate:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"view:willDisplayImage:",
        {"retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSValue",
        b"QTTimeRangeValue",
        {
            "retval": {
                "type": sel32or64(
                    b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                    b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                )
            }
        },
    )
    r(
        b"NSValue",
        b"QTTimeValue",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"NSValue",
        b"valueWithQTTime:",
        {"arguments": {2: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}}},
    )
    r(
        b"NSValue",
        b"valueWithQTTimeRange:",
        {
            "arguments": {
                2: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                }
            }
        },
    )
    r(b"QTCaptureConnection", b"attributeIsReadOnly:", {"retval": {"type": "Z"}})
    r(b"QTCaptureConnection", b"isEnabled", {"retval": {"type": "Z"}})
    r(b"QTCaptureConnection", b"setEnabled:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"QTCaptureDecompressedVideoOutput",
        b"automaticallyDropsLateVideoFrames",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"QTCaptureDecompressedVideoOutput",
        b"setAutomaticallyDropsLateVideoFrames:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"QTCaptureDevice", b"attributeIsReadOnly:", {"retval": {"type": "Z"}})
    r(b"QTCaptureDevice", b"hasMediaType:", {"retval": {"type": "Z"}})
    r(b"QTCaptureDevice", b"isConnected", {"retval": {"type": "Z"}})
    r(b"QTCaptureDevice", b"isInUseByAnotherApplication", {"retval": {"type": "Z"}})
    r(b"QTCaptureDevice", b"isOpen", {"retval": {"type": "Z"}})
    r(
        b"QTCaptureDevice",
        b"open:",
        {"retval": {"type": "Z"}, "arguments": {2: {"type_modifier": b"o"}}},
    )
    r(b"QTCaptureFileOutput", b"isRecordingPaused", {"retval": {"type": b"Z"}})
    r(
        b"QTCaptureFileOutput",
        b"maximumRecordedDuration",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTCaptureFileOutput",
        b"recordedDuration",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTCaptureFileOutput",
        b"setMaximumRecordedDuration:",
        {"arguments": {2: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}}},
    )
    r(
        b"QTCaptureSession",
        b"addInput:error:",
        {"retval": {"type": "Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"QTCaptureSession",
        b"addOutput:error:",
        {"retval": {"type": "Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"QTCaptureSession", b"isRunning", {"retval": {"type": "Z"}})
    r(b"QTCaptureView", b"preservesAspectRatio", {"retval": {"type": "Z"}})
    r(b"QTCaptureView", b"setPreservesAspectRatio:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"QTCompressionOptions",
        b"isEqualToCompressionOptions:",
        {"retval": {"type": "Z"}},
    )
    r(b"QTDataReference", b"dataRef", {"retval": {"type": "^*"}})
    r(
        b"QTDataReference",
        b"dataReferenceWithDataRef:type:",
        {"arguments": {2: {"type": "^*"}}},
    )
    r(b"QTDataReference", b"initWithDataRef:type:", {"arguments": {2: {"type": "^*"}}})
    r(b"QTDataReference", b"setDataRef:", {"arguments": {2: {"type": "^*"}}})
    r(
        b"QTExportSession",
        b"initWithMovie:exportOptions:outputURL:error:",
        {"arguments": {5: {"type_modifier": b"o"}}},
    )
    r(b"QTExportSession", b"isCancelled", {"retval": {"type": "Z"}})
    r(b"QTExportSession", b"isFinished", {"retval": {"type": "Z"}})
    r(b"QTExportSession", b"isRunning", {"retval": {"type": "Z"}})
    r(
        b"QTExportSession",
        b"waitUntilFinished:",
        {"retval": {"type": "Z"}, "arguments": {2: {"type_modifier": b"o"}}},
    )
    r(b"QTFormatDescription", b"isEqualToFormatDescription:", {"retval": {"type": "Z"}})
    r(b"QTMedia", b"hasCharacteristic:", {"retval": {"type": "Z"}})
    r(
        b"QTMedia",
        b"initWithQuickTimeMedia:error:",
        {"arguments": {2: {"type": "^^{MediaType}"}, 3: {"type_modifier": b"o"}}},
    )
    r(
        b"QTMedia",
        b"mediaWithQuickTimeMedia:error:",
        {"arguments": {2: {"type": "^^{MediaType}"}, 3: {"type_modifier": b"o"}}},
    )
    r(b"QTMedia", b"quickTimeMedia", {"retval": {"type": "^^{MediaType}"}})
    r(
        b"QTMovie",
        b"addChapters:withAttributes:error:",
        {"arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"QTMovie",
        b"addImage:forDuration:withAttributes:",
        {"arguments": {3: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}}},
    )
    r(b"QTMovie", b"attachToCurrentThread", {"retval": {"type": "Z"}})
    r(b"QTMovie", b"canInitWithDataReference:", {"retval": {"type": "Z"}})
    r(b"QTMovie", b"canInitWithFile:", {"retval": {"type": "Z"}})
    r(b"QTMovie", b"canInitWithPasteboard:", {"retval": {"type": "Z"}})
    r(b"QTMovie", b"canInitWithURL:", {"retval": {"type": "Z"}})
    r(b"QTMovie", b"canUpdateMovieFile", {"retval": {"type": "Z"}})
    r(
        b"QTMovie",
        b"chapterIndexForTime:",
        {"arguments": {2: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}}},
    )
    r(
        b"QTMovie",
        b"currentTime",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTMovie",
        b"deleteSegment:",
        {
            "arguments": {
                2: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                }
            }
        },
    )
    r(b"QTMovie", b"detachFromCurrentThread", {"retval": {"type": "Z"}})
    r(
        b"QTMovie",
        b"duration",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTMovie",
        b"frameImageAtTime:",
        {"arguments": {2: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}}},
    )
    r(
        b"QTMovie",
        b"frameImageAtTime:withAttributes:error:",
        {
            "retval": {"type": "^v"},
            "arguments": {
                2: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")},
                4: {"type_modifier": b"o"},
            },
        },
    )
    r(b"QTMovie", b"hasChapters", {"retval": {"type": "Z"}})
    r(
        b"QTMovie",
        b"initToWritableData:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"QTMovie",
        b"initToWritableDataReference:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"QTMovie",
        b"initToWritableFile:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"QTMovie",
        b"initWithAttributes:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"QTMovie", b"initWithData:error:", {"arguments": {3: {"type_modifier": b"o"}}})
    r(
        b"QTMovie",
        b"initWithDataReference:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"QTMovie", b"initWithFile:error:", {"arguments": {3: {"type_modifier": b"o"}}})
    r(
        b"QTMovie",
        b"initWithMovie:timeRange:error:",
        {
            "arguments": {
                3: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                4: {"type_modifier": b"o"},
            }
        },
    )
    r(
        b"QTMovie",
        b"initWithPasteboard:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"QTMovie",
        b"initWithQuickTimeMovie:disposeWhenDone:error:",
        {
            "arguments": {
                2: {"type": "^^{MovieType}"},
                3: {"type": "Z"},
                4: {"type_modifier": b"o"},
            }
        },
    )
    r(b"QTMovie", b"initWithURL:error:", {"arguments": {3: {"type_modifier": b"o"}}})
    r(
        b"QTMovie",
        b"insertEmptySegmentAt:",
        {
            "arguments": {
                2: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                }
            }
        },
    )
    r(
        b"QTMovie",
        b"insertSegmentOfMovie:fromRange:scaledToRange:",
        {
            "arguments": {
                3: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                4: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
            }
        },
    )
    r(
        b"QTMovie",
        b"insertSegmentOfMovie:timeRange:atTime:",
        {
            "arguments": {
                3: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                4: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")},
            }
        },
    )
    r(
        b"QTMovie",
        b"insertSegmentOfTrack:fromRange:scaledToRange:",
        {
            "arguments": {
                3: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                4: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
            }
        },
    )
    r(
        b"QTMovie",
        b"insertSegmentOfTrack:timeRange:atTime:",
        {
            "arguments": {
                3: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                4: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")},
            }
        },
    )
    r(b"QTMovie", b"isIdling", {"retval": {"type": "Z"}})
    r(b"QTMovie", b"movieNamed:error:", {"arguments": {3: {"type_modifier": b"o"}}})
    r(
        b"QTMovie",
        b"movieWithAttributes:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"QTMovie", b"movieWithData:error:", {"arguments": {3: {"type_modifier": b"o"}}})
    r(
        b"QTMovie",
        b"movieWithDataReference:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"QTMovie", b"movieWithFile:error:", {"arguments": {3: {"type_modifier": b"o"}}})
    r(
        b"QTMovie",
        b"movieWithPasteboard:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"QTMovie",
        b"movieWithQuickTimeMovie:disposeWhenDone:error:",
        {
            "arguments": {
                2: {"type": "^^{MovieType}"},
                3: {"type": "Z"},
                4: {"type_modifier": b"o"},
            }
        },
    )
    r(
        b"QTMovie",
        b"movieWithTimeRange:error:",
        {
            "arguments": {
                2: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                3: {"type_modifier": b"o"},
            }
        },
    )
    r(b"QTMovie", b"movieWithURL:error:", {"arguments": {3: {"type_modifier": b"o"}}})
    r(b"QTMovie", b"muted", {"retval": {"type": "Z"}})
    r(b"QTMovie", b"quickTimeMovie", {"retval": {"type": "^^{MovieType}"}})
    r(
        b"QTMovie",
        b"quickTimeMovieController",
        {"retval": {"type": "^{ComponentInstanceRecord=[1l]}"}},
    )
    r(b"QTMovie", b"removeChapters", {"retval": {"type": "Z"}})
    r(
        b"QTMovie",
        b"scaleSegment:newDuration:",
        {
            "arguments": {
                2: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                3: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")},
            }
        },
    )
    r(
        b"QTMovie",
        b"selectionDuration",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTMovie",
        b"selectionEnd",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTMovie",
        b"selectionStart",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTMovie",
        b"setCurrentTime:",
        {"arguments": {2: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}}},
    )
    r(b"QTMovie", b"setIdling:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovie", b"setMuted:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"QTMovie",
        b"setSelection:",
        {
            "arguments": {
                2: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                }
            }
        },
    )
    r(
        b"QTMovie",
        b"setVisualContext:",
        {"arguments": {2: {"type": "^{OpaqueQTVisualContext=}"}}},
    )
    r(
        b"QTMovie",
        b"startTimeOfChapter:",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTMovie",
        b"trackByInsertingSegmentOfTrack:fromRange:scaledToRange:",
        {
            "arguments": {
                3: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                4: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
            }
        },
    )
    r(
        b"QTMovie",
        b"trackByInsertingSegmentOfTrack:timeRange:atTime:",
        {
            "arguments": {
                3: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                4: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")},
            }
        },
    )
    r(b"QTMovie", b"updateMovieFile", {"retval": {"type": "Z"}})
    r(b"QTMovie", b"visualContext", {"retval": {"type": "^{OpaqueQTVisualContext=}"}})
    r(b"QTMovie", b"writeToFile:withAttributes:", {"retval": {"type": "Z"}})
    r(
        b"QTMovie",
        b"writeToFile:withAttributes:error:",
        {"retval": {"type": "Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"QTMovieModernizer",
        b"modernizeWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"QTMovieModernizer",
        b"requiresModernization:error:",
        {"retval": {"type": "Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"QTMovieView", b"areStepButtonsVisible", {"retval": {"type": "Z"}})
    r(b"QTMovieView", b"areZoomButtonsVisible", {"retval": {"type": "Z"}})
    r(b"QTMovieView", b"isBackButtonVisible", {"retval": {"type": "Z"}})
    r(b"QTMovieView", b"isControllerVisible", {"retval": {"type": "Z"}})
    r(b"QTMovieView", b"isCustomButtonVisible", {"retval": {"type": "Z"}})
    r(b"QTMovieView", b"isEditable", {"retval": {"type": "Z"}})
    r(b"QTMovieView", b"isHotSpotButtonVisible", {"retval": {"type": "Z"}})
    r(b"QTMovieView", b"isTranslateButtonVisible", {"retval": {"type": "Z"}})
    r(b"QTMovieView", b"isVolumeButtonVisible", {"retval": {"type": "Z"}})
    r(b"QTMovieView", b"preservesAspectRatio", {"retval": {"type": "Z"}})
    r(b"QTMovieView", b"setBackButtonVisible:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovieView", b"setControllerVisible:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovieView", b"setCustomButtonVisible:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovieView", b"setEditable:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovieView", b"setHotSpotButtonVisible:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovieView", b"setPreservesAspectRatio:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovieView", b"setShowsResizeIndicator:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovieView", b"setStepButtonsVisible:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovieView", b"setTranslateButtonVisible:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovieView", b"setVolumeButtonVisible:", {"arguments": {2: {"type": "Z"}}})
    r(b"QTMovieView", b"setZoomButtonsVisible:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"QTSampleBuffer",
        b"decodeTime",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTSampleBuffer",
        b"duration",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTSampleBuffer",
        b"getAudioStreamPacketDescriptions:inRange:",
        {"retval": {"type": "Z"}},
    )
    r(
        b"QTSampleBuffer",
        b"presentationTime",
        {"retval": {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}},
    )
    r(
        b"QTTrack",
        b"addImage:forDuration:withAttributes:",
        {"arguments": {3: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")}}},
    )
    r(
        b"QTTrack",
        b"deleteSegment:",
        {
            "arguments": {
                2: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                }
            }
        },
    )
    r(
        b"QTTrack",
        b"initWithQuickTimeTrack:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"QTTrack",
        b"insertEmptySegmentAt:",
        {
            "arguments": {
                2: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                }
            }
        },
    )
    r(
        b"QTTrack",
        b"insertSegmentOfTrack:fromRange:scaledToRange:",
        {
            "arguments": {
                3: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                4: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
            }
        },
    )
    r(
        b"QTTrack",
        b"insertSegmentOfTrack:timeRange:atTime:",
        {
            "arguments": {
                3: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                4: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")},
            }
        },
    )
    r(b"QTTrack", b"isEnabled", {"retval": {"type": "Z"}})
    r(
        b"QTTrack",
        b"scaleSegment:newDuration:",
        {
            "arguments": {
                2: {
                    "type": sel32or64(
                        b"{_QTTimeRange={_QTTime=qll}{_QTTime=qll}}",
                        b"{_QTTimeRange={_QTTime=qqq}{_QTTime=qqq}}",
                    )
                },
                3: {"type": sel32or64(b"{_QTTime=qll}", b"{_QTTime=qqq}")},
            }
        },
    )
    r(b"QTTrack", b"setEnabled:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"QTTrack",
        b"trackWithQuickTimeTrack:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
finally:
    objc._updatingMetadata(False)
protocols = {
    "QTCaptureDecompressedVideoOutput_Delegate": objc.informal_protocol(
        "QTCaptureDecompressedVideoOutput_Delegate",
        [
            objc.selector(
                None,
                b"captureOutput:didOutputVideoFrame:withSampleBuffer:fromConnection:",
                b"v@:@^{__CVBuffer=}@@",
                isRequired=False,
            ),
            objc.selector(
                None,
                b"captureOutput:didDropVideoFrameWithSampleBuffer:fromConnection:",
                b"v@:@@@",
                isRequired=False,
            ),
        ],
    ),
    "QTMovieView_Delegate": objc.informal_protocol(
        "QTMovieView_Delegate",
        [
            objc.selector(None, b"view:willDisplayImage:", b"@@:@@", isRequired=False),
            objc.selector(None, b"menuForEventDelegate:", b"@@:@", isRequired=False),
        ],
    ),
    "QTCaptureVideoPreviewOutput_Delegate": objc.informal_protocol(
        "QTCaptureVideoPreviewOutput_Delegate",
        [
            objc.selector(
                None,
                b"captureOutput:didOutputVideoFrame:withSampleBuffer:fromConnection:",
                b"v@:@^{__CVBuffer=}@@",
                isRequired=False,
            )
        ],
    ),
    "QTCaptureView_Delegate": objc.informal_protocol(
        "QTCaptureView_Delegate",
        [objc.selector(None, b"view:willDisplayImage:", b"@@:@@", isRequired=False)],
    ),
    "QTCaptureDecompressedAudioOutput_Delegate": objc.informal_protocol(
        "QTCaptureDecompressedAudioOutput_Delegate",
        [
            objc.selector(
                None,
                b"captureOutput:didOutputAudioSampleBuffer:fromConnection:",
                b"v@:@@@",
                isRequired=False,
            )
        ],
    ),
    "QTCaptureFileOutput_Delegate": objc.informal_protocol(
        "QTCaptureFileOutput_Delegate",
        [
            objc.selector(
                None,
                b"captureOutput:didOutputSampleBuffer:fromConnection:",
                b"v@:@@@",
                isRequired=False,
            ),
            objc.selector(
                None,
                b"captureOutput:didResumeRecordingToOutputFileAtURL:forConnections:",
                b"v@:@@@",
                isRequired=False,
            ),
            objc.selector(
                None,
                b"captureOutput:shouldChangeOutputFileAtURL:forConnections:dueToError:",
                b"Z@:@@@@",
                isRequired=False,
            ),
            objc.selector(
                None,
                b"captureOutput:didStartRecordingToOutputFileAtURL:forConnections:",
                b"v@:@@@",
                isRequired=False,
            ),
            objc.selector(
                None,
                b"captureOutput:willFinishRecordingToOutputFileAtURL:forConnections:dueToError:",
                b"v@:@@@@",
                isRequired=False,
            ),
            objc.selector(
                None,
                b"captureOutput:didPauseRecordingToOutputFileAtURL:forConnections:",
                b"v@:@@@",
                isRequired=False,
            ),
            objc.selector(
                None,
                b"captureOutput:mustChangeOutputFileAtURL:forConnections:dueToError:",
                b"v@:@@@@",
                isRequired=False,
            ),
            objc.selector(
                None,
                b"captureOutput:didFinishRecordingToOutputFileAtURL:forConnections:dueToError:",
                b"v@:@@@@",
                isRequired=False,
            ),
            objc.selector(
                None,
                b"captureOutput:willStartRecordingToOutputFileAtURL:forConnections:",
                b"v@:@@@",
                isRequired=False,
            ),
        ],
    ),
    "QTMovie_Delegate": objc.informal_protocol(
        "QTMovie_Delegate",
        [
            objc.selector(None, b"setDelegate:", b"v@:@", isRequired=False),
            objc.selector(None, b"delegate", b"@@:", isRequired=False),
        ],
    ),
}
expressions = {}

# END OF FILE



"""
Python mapping for the QTKit framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""
import sys

import Cocoa
import objc
import Quartz
from QTKit import _metadata, _QTKit

sys.modules["QTKit"] = mod = objc.ObjCLazyModule(
    "QTKit",
    "com.apple.QTKit",
    objc.pathForFramework("/System/Library/Frameworks/QTKit.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
        "objc": objc,
    },
    (_QTKit, Cocoa, Quartz),
)


del sys.modules["QTKit._metadata"]
del sys.modules["QTKit._QTKit"]



"""
Wrappers for the "QTKit" framework on macOS.  QTKit is an modern,
object-oriented framework for working with QuickTime media in Cocoa
applications, and is a replacement for the older Carbon-based Quicktime
framework.

These wrappers don't include documentation, please check Apple's documention
for information on how to use this framework and PyObjC's documentation
for general tips and tricks regarding the translation between Python
and (Objective-)C frameworks

Note that this framework is deprecated in OSX 10.9
"""
import os

from pyobjc_setup import Extension, setup

VERSION = "6.2.2"

setup(
    name="pyobjc-framework-QTKit",
    description="Wrappers for the framework QTKit on macOS",
    max_os_level="10.14",
    packages=["QTKit"],
    ext_modules=[
        Extension(
            "QTKit._QTKit",
            ["Modules/_QTKit.m"],
            extra_link_args=["-framework", "QTKit"],
            py_limited_api=True,
            depends=[
                os.path.join("Modules", fn)
                for fn in os.listdir("Modules")
                if fn.startswith("_QTKit")
            ],
        )
    ],
    version=VERSION,
    install_requires=[
        "pyobjc-core>=" + VERSION,
        "pyobjc-framework-Cocoa>=" + VERSION,
        "pyobjc-framework-Quartz>=" + VERSION,
    ],
    long_description=__doc__,
    options={"bdist_wheel": {"py_limited_api": "cp36"}},
)
